@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheRFC1867Parser.cpp 2162 2006-12-03 14:36:10Z svn $
+ * $Id: ApacheRFC1867Parser.cpp 2696 2007-11-18 14:46:40Z svn $
  *****************************************************************************/
 
 #include "ApacheRFC1867Parser.h"
@@ -34,7 +34,10 @@
 #include "MultipartMessageParser.cpp"
 #include "RFC1867Parser.cpp"
 
-SOURCE_INFO_ADD("$Id: ApacheRFC1867Parser.cpp 2162 2006-12-03 14:36:10Z svn $");
+#include "BasicFileWriter.cpp"
+#include "MmapFileWriter.cpp"
+
+SOURCE_INFO_ADD("$Id: ApacheRFC1867Parser.cpp 2696 2007-11-18 14:46:40Z svn $");
 
 template class MultipartMessageParser<ApacheRequestReader>;
 template class RFC1867Parser<ApacheRequestReader>;
