@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 2620 2007-11-02 16:36:07Z svn $
+ * $Id: UploadItem.cpp 2676 2007-11-17 15:03:20Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItem.cpp 2620 2007-11-02 16:36:07Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItem.cpp 2676 2007-11-17 15:03:20Z svn $");
 
 #define AS_BCOMMENT(pointer)        reinterpret_cast<bbs_comment_t *>(pointer)
 #define UINT16(pointer)             static_cast<apr_uint16_t>(pointer)
@@ -159,8 +159,8 @@ int UploadItem::cmp_comment(const UploadItem *a, const UploadItem *b)
 
 int UploadItem::cmp_download_count(const UploadItem *a, const UploadItem *b)
 {
-    apr_atomic_t a_download_count;
-    apr_atomic_t b_download_count;
+    apr_size_t a_download_count;
+    apr_size_t b_download_count;
 
     a_download_count = a->get_download_count();
     b_download_count = b->get_download_count();
