@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemListReader.cpp 2564 2007-10-10 14:08:20Z svn $
+ * $Id: UploadItemListReader.cpp 2590 2007-10-20 15:40:45Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2564 2007-10-10 14:08:20Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemListReader.cpp 2590 2007-10-20 15:40:45Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -76,7 +76,8 @@ UploadItemList *UploadItemListReader::read(apr_pool_t *pool,
     item_list = UploadItemList::get_instance(shm,
                                              max_file_size, max_list_size);
 
-    while (apr_dir_read(&sub_dir_info, APR_FINFO_NAME|APR_FINFO_TYPE,
+    while (apr_dir_read(&sub_dir_info,
+                        APR_FINFO_NAME|APR_FINFO_TYPE|APR_FINFO_MTIME,
                         dir) == APR_SUCCESS) {
         if ((sub_dir_info.filetype != APR_DIR) ||
             !is_subdir_name_valid(sub_dir_info.name)) {
