@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2662 2007-11-16 16:58:55Z svn $
+ * $Id: uploader_handler.cpp 2691 2007-11-18 05:45:31Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2662 2007-11-16 16:58:55Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2691 2007-11-18 05:45:31Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -508,7 +508,7 @@ static int upload_impl(typename Response::Handle *r, UploaderConfig *config,
 
     Response::set_env(r, "uploader_upload", "");
     Response::set_env(r, "uploader_item_id",
-                      apr_psprintf(r->pool, "%u", *item_id));
+                      apr_psprintf(r->pool, "%" APR_SIZE_T_FMT, *item_id));
 
     typename Response::Writer o(r);
 
@@ -516,7 +516,7 @@ static int upload_impl(typename Response::Handle *r, UploaderConfig *config,
         (r, o,
          apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR,
                      INFO_COMMAND, ARG_SEPARATE_STR,
-                     apr_psprintf(r->pool, "%u", *item_id),
+                     apr_psprintf(r->pool, "%" APR_SIZE_T_FMT, *item_id),
                      NULL));
 }
 
@@ -761,9 +761,27 @@ static int download_set_header(typename Response::Handle *r, UploadItem *uitem)
         return OK;
 }
 
+// TODO: ApacheResponse.h に移動させる
 template<class Response>
-static int download_impl(typename Response::Handle *r, UploadItem *uitem,
-                         apr_file_t *item_file, const char *mode)
+static bool is_gzip_accepted(typename Response::Handle *r)
+{
+#ifdef UPLOADER_TYPE_APACHE
+    const char *accepted;
+
+    accepted = apr_table_get(r->headers_in, "Accept-Encoding");
+    if (accepted == NULL) {
+        return false;
+    }
+    return strstr(accepted, "gzip") != NULL;
+#else
+    return true;
+#endif
+}
+
+template<class Response>
+static int download_impl(typename Response::Handle *r, UploaderConfig *config,
+                         UploadItem *uitem, apr_file_t *item_file,
+                         const char *mode)
 {
     int status;
 
@@ -779,11 +797,25 @@ static int download_impl(typename Response::Handle *r, UploadItem *uitem,
     }
 
     Response::set_content_disposition(r, mode);
+
+#if defined(USE_GZIP) && defined(UPLOADER_TYPE_APACHE)
+    if (!is_gzip_accepted<Response>(r)) {
+        typename Response::Writer o(r);
+
+        return error<Response>(r, o, config, MESSAGE_DOWNLOAD_GZIP_NEEDED);
+    }
+
+    // mod_deflate が動かないようにする
+    apr_table_setn(r->subprocess_env, "no-gzip", "no-gzip");
+
+    apr_table_setn(r->headers_out, "Content-Encoding", "gzip");
+#endif
+
     Response::header_end(r);
 
     Response::set_env(r, "uploader_download", "");
     Response::set_env(r, "uploader_item_id",
-                      apr_psprintf(r->pool, "%u", uitem->get_id()));
+                      apr_psprintf(r->pool, "%" APR_SIZE_T_FMT, uitem->get_id()));
 
     // better to use ap_internal_fast_redirect for Apache
     Response::Writer::sendfile(r, item_file, uitem->get_file_size());
@@ -825,37 +857,11 @@ static int download_prep(typename Response::Handle *r, UploaderConfig *config,
         (r, o,
          apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR,
                      DOWNLOAD_COMMAND, ARG_SEPARATE_STR,
-                     apr_psprintf(r->pool, "%u", uitem->get_id()),
+                     apr_psprintf(r->pool, "%" APR_SIZE_T_FMT, uitem->get_id()),
                      ARG_SEPARATE_STR, "attach", ARG_SEPARATE_STR,
                      rfc2396_encode(r->pool, file_name), NULL));
 }
 
-template<class Response>
-static int download_view(typename Response::Handle *r, UploadItem *uitem,
-                         apr_file_t *item_file)
-{
-    int status;
-
-    status = download_set_header<Response>(r, uitem);
-    if (status != OK) {
-        Response::header_end(r);
-        return status;
-    }
-
-    if (Response::is_head_method(r)) {
-        Response::header_end(r);
-        return OK;
-    }
-
-    Response::set_content_disposition(r, "inline");
-    Response::header_end(r);
-
-    // better to use ap_internal_fast_redirect for Apache
-    Response::Writer::sendfile(r, item_file, uitem->get_file_size());
-
-    return OK;
-}
-
 template<class Response>
 static int download(typename Response::Handle *r, UploaderConfig *config,
                     const char *arg, bool is_admin_mode=false)
@@ -946,14 +952,15 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
 
         if (is_view_mode) {
             // 表示
-            return download_impl<Response>(r, uitem, item_file, "inline");
+            return download_impl<Response>(r, config, uitem, item_file,
+                                           "inline");
         } else {
             if (strlen(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])) == 0) {
                 // ファイル名を追加した URL に飛ばす
                 return download_prep<Response>(r, config, uitem);
             } else {
                 // ダウンロード
-                return download_impl<Response>(r, uitem, item_file,
+                return download_impl<Response>(r, config, uitem, item_file,
                                                "attachment");
             }
         }
@@ -1020,7 +1027,7 @@ static int remove(typename Response::Handle *r, UploaderConfig *config,
         } else {
             Response::set_env(r, "uploader_remove", "");
             Response::set_env(r, "uploader_item_id",
-                              apr_psprintf(r->pool, "%u", item_id));
+                              apr_psprintf(r->pool, "%" APR_SIZE_T_FMT, item_id));
 
             return redirect<Response>
                 (r, o,
