@@ -31,6 +31,7 @@ use strict;
 use Expect;
 use Term::ReadLine;
 use Term::ReadPassword;
+use Net::Ping::External qw{ ping };;
 use File::Basename;
 
 use constant BASE_DIR           => dirname($0) . '/../..';
@@ -40,9 +41,9 @@ use constant MAKE_TIMEOUT_SEC   => 3600;
 use constant WINDOWS_HOSTNAME   => 'brazil';
 use constant VMWARE_CMD_PATH    => 'C:/Application/Machine/VMware/VMware Server/vmware-cmd.bat';
 
-use constant SHUTDOWN_WAIT_SEC  => 180;
-use constant BOOT_INTERVAL_SEC  => 60;
-use constant BOOT_WAIT_SEC      => 600;
+use constant SHUTDOWN_WAIT_SEC  => 10;
+use constant BOOT_INTERVAL_SEC  => 120;
+use constant BOOT_WAIT_SEC      => 10;
 
 my %VIRTUAL_MACHINE = (
     centos  => 'D:\\VMware\\CentOS\\CentOS.vmx',
@@ -68,7 +69,7 @@ sub ssh_login {
     my $exp = shift;
     my $pass = shift;
 
-    $exp->spawn('ssh', WINDOWS_HOSTNAME) or die $!;
+    $exp->spawn('cocot', qw(-t EUC-JP -p CP932 ssh), WINDOWS_HOSTNAME) or die $!;
     $exp->expect(CMD_TIMEOUT_SEC, 'password:');
     $exp->send($pass . "\n");
     $exp->expect(CMD_TIMEOUT_SEC, 'successfully');
@@ -92,7 +93,8 @@ sub start_machine {
     my $exp = shift;
     my $name = shift;
 
-    $exp->send('"' . VMWARE_CMD_PATH . '" ' . $VIRTUAL_MACHINE{$name} . ' start | nkf -e' . "\n");
+    $exp->send('"' . VMWARE_CMD_PATH . '" ' . $VIRTUAL_MACHINE{$name} .
+               ' start' . "\n");
     $exp->expect(CMD_TIMEOUT_SEC, '>');
 }
 
@@ -100,11 +102,8 @@ sub stop_machine {
     my $exp = shift;
     my $name = shift;
 
-    # եȥŪ shutdown Ԥ
-    `ssh $name "sudo /sbin/shutdown -h now"`;
-    sleep(SHUTDOWN_WAIT_SEC);
-
-    $exp->send('"' . VMWARE_CMD_PATH . '" ' . $VIRTUAL_MACHINE{$name} . ' stop hard | nkf -e' . "\n");
+    $exp->send('"' . VMWARE_CMD_PATH . '" ' . $VIRTUAL_MACHINE{$name} .
+               ' stop hard' . "\n");
     $exp->expect(CMD_TIMEOUT_SEC, '>');
 }
 
@@ -119,18 +118,61 @@ ssh_login($exp, $pass);
 set_env($exp);
 
 # Сޥεư
-foreach my $name (keys %VIRTUAL_MACHINE) {
+foreach my $name (sort keys %VIRTUAL_MACHINE) {
+    if (ping(host => $name)) {
+        next;
+    }
     start_machine($exp, $name);
     sleep(BOOT_INTERVAL_SEC);
 }
-sleep(BOOT_WAIT_SEC);
+
+# СޥεưԤ
+while (1) {
+    my $not_ready = 0;
+
+    foreach my $name (sort keys %VIRTUAL_MACHINE) {
+        if (system("ssh-keyscan -t rsa $name >/dev/null 2>&1") != 0) {
+            printf("%s is not ready.\n", $name);
+            $not_ready++;
+        }
+    }
+    sleep(BOOT_WAIT_SEC);
+
+    if ($not_ready == 0) {
+        last;
+    }
+}
 
 # ƥȤμ¹
 system("make -C @{[BASE_DIR]} -f GNUmakefile.dist test-linux");
 system("make -C @{[BASE_DIR]} -f GNUmakefile.dist test-bsd");
 
+# shutdown ޥɤȯ
+foreach my $name (sort keys %VIRTUAL_MACHINE) {
+    if ($name =~ /bsd/i) {
+        system("ssh $name sudo /sbin/shutdown -p now");
+    } else {
+        system("ssh $name sudo /sbin/shutdown -h now");
+    }
+}
+
+while (1) {
+    my $alive = 0;
+
+    foreach my $name (sort keys %VIRTUAL_MACHINE) {
+        if (ping(host => $name)) {
+            $alive++;
+        }
+    }
+    sleep(SHUTDOWN_WAIT_SEC);
+
+    if ($alive == 0) {
+        last;
+    }
+}
+
 # Сޥ
-foreach my $name (keys %VIRTUAL_MACHINE) {
+foreach my $name (sort keys %VIRTUAL_MACHINE) {
     stop_machine($exp, $name);
 }
 exit_cmd($exp);
