@@ -23,6 +23,7 @@ namespace UploaderConfig
         private uint perPageItemNumber_;
 
         private string indexTmplPath_;
+        private string infoTmplPath_;
         private string progressTmplPath_;
         private string downloadTmplPath_;
         private string thumbnailTmplPath_;
@@ -61,6 +62,7 @@ namespace UploaderConfig
             string tmplDirPath = Path.Combine(baseDir, "tmpl");
 
             indexTmplPath     = Path.Combine(tmplDirPath, "index.htm");
+            infoTmplPath      = Path.Combine(tmplDirPath, "info.htm");
             progressTmplPath  = Path.Combine(tmplDirPath, "progress.htm");
             downloadTmplPath  = Path.Combine(tmplDirPath, "download.htm");
             thumbnailTmplPath = Path.Combine(tmplDirPath, "thumbnail.htm");
@@ -183,6 +185,15 @@ namespace UploaderConfig
                 updateConfigText();
             }
         }
+        public string infoTmplPath
+        {
+            get { return infoTmplPath_; }
+            set
+            {
+                infoTmplPath_ = value;
+                updateConfigText();
+            }
+        }
         public string progressTmplPath
         {
             get { return progressTmplPath_; }
